@@ -6,7 +6,7 @@ class SingleLayerPerceptron:
     self.epochs_ = int(epochs)
     self.mini_batch_ = int(mini_batch)
     self.report_=report
-    self.MODEL_ = LinearModel
+    self.MODEL_ = MODEL
     self.learning_rate_ = learning_rate
 
 
@@ -15,7 +15,6 @@ class SingleLayerPerceptron:
     if str(type(y)) == "<class 'pandas.core.series.Series'>": y = y.to_numpy().reshape(-1,1)
 
     steps = int(X.shape[0]//self.mini_batch_) # 미니배치가 가능한 갯수
-    self.model = self.MODEL_(int(X.shape[1]))
     self.model = self.MODEL_(int(X.shape[1]), self.learning_rate_)
     # self.model = LinearModel(int(X.shape[1]), self.learning_rate_)
 
